==> connector-service-1.0.0-20190724.130205-34-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class MemberOpenCardRequestVO extends BaseModel{

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 有效期
     */
    private String effectiveTime;

    /**
     * 开卡来源
     */
    private String source;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 开卡区别来源UR
     */
    private String registerType;

    /**
     * 所属门店UR
     */
    private String serviceStoreCode;

    /**
     * 密码UR
     */
    private String password;

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getRegisterType() {
        return registerType;
    }

    public void setRegisterType(String registerType) {
        this.registerType = registerType;
    }

    public String getServiceStoreCode() {
        return serviceStoreCode;
    }

    public void setServiceStoreCode(String serviceStoreCode) {
        this.serviceStoreCode = serviceStoreCode;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}

==> connector-service-1.0.0-20191029.065603-81-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class MemberOpenCardRequestVO extends BaseModel{

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 有效期
     */
    private String effectiveTime;

    /**
     * 开卡来源
     */
    private String source;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 开卡区别来源UR
     */
    private String registerType;

    /**
     * 所属门店UR
     */
    private String serviceStoreCode;

    /**
     * 密码UR
     */
    private String password;

    private String taobaoNick;

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getRegisterType() {
        return registerType;
    }

    public void setRegisterType(String registerType) {
        this.registerType = registerType;
    }

    public String getServiceStoreCode() {
        return serviceStoreCode;
    }

    public void setServiceStoreCode(String serviceStoreCode) {
        this.serviceStoreCode = serviceStoreCode;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getTaobaoNick() {
        return taobaoNick;
    }

    public void setTaobaoNick(String taobaoNick) {
        this.taobaoNick = taobaoNick;
    }
}
